@@ -390,9 +390,25 @@ class Zstd(_FilterRefClass):
             data=numpy.arange(100),
             **hdf5plugin.Zstd())
         f.close()
+
+    :param int clevel: Compression level from 1 (lowest compression) to 22 (maximum compression).
+        Ultra compression extends from 20 through 22. Default: 3.
+
+    .. code-block:: python
+
+        f = h5py.File('test.h5', 'w')
+        f.create_dataset(
+            'zstd',
+            data=numpy.arange(100),
+            **hdf5plugin.Zstd(clevel=22))
+        f.close()
     """
     filter_id = ZSTD_ID
 
+    def __init__(self, clevel=3):
+        assert 1 <= clevel <= 22
+        self.filter_options = (clevel,)
+
 
 def _init_filters():
     """Initialise and register HDF5 filters with h5py
@@ -402,15 +418,15 @@ def _init_filters():
     hdf5_version = _h5py.h5.get_libversion()
 
     for name, filter_id in FILTERS.items():
-        # Skip "optional" filters if not built
-        if name == 'fcidecomp' and not config.cpp11:
-            _logger.info("%s filter not available in this build of hdf5plugin.", name)
+        # Skip filters that were not embedded
+        if name not in config.embedded_filters:
+            _logger.debug("%s filter not available in this build of hdf5plugin.", name)
             continue
 
         # Check if filter is already loaded (not on buggy HDF5 versions)
         if (1, 8, 20) <= hdf5_version < (1, 10) or hdf5_version >= (1, 10, 2):
             if _h5py.h5z.filter_avail(filter_id):
-                _logger.warning("%s filter already loaded, skip it.", name)
+                _logger.info("%s filter already loaded, skip it.", name)
                 continue
 
         # Load DLL
